@@ -1,3 +1,5 @@
+import statistics
+
 from django.contrib import admin
 from django.db import models
 from django.db.models import Count
@@ -9,19 +11,8 @@ from allianceauth.services.hooks import get_extension_logger
 from app_utils.django import admin_boolean_icon_html
 from app_utils.logging import LoggerAddTag
 
-from . import __title__, tasks
-from .app_settings import STRUCTURES_DEVELOPER_MODE
+from . import __title__, app_settings, tasks
 from .models import (
-    EveCategory,
-    EveConstellation,
-    EveEntity,
-    EveGroup,
-    EveMoon,
-    EvePlanet,
-    EveRegion,
-    EveSolarSystem,
-    EveSovereigntyMap,
-    EveType,
     Notification,
     Owner,
     Structure,
@@ -33,66 +24,6 @@ from .models import (
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
-if STRUCTURES_DEVELOPER_MODE:
-
-    @admin.register(EveConstellation)
-    class EveConstellationAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveEntity)
-    class EveEntityAdmin(admin.ModelAdmin):
-        list_display = (
-            "id",
-            "name",
-            "category",
-        )
-        list_filter = ("category",)
-        list_display_links = None
-
-    @admin.register(EveCategory)
-    class EveCategoryAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveGroup)
-    class EveGroupAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveMoon)
-    class EveMoonAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EvePlanet)
-    class EvePlanetAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveRegion)
-    class EveRegionAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveSolarSystem)
-    class EveSolarSystemAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveType)
-    class EveTypeAdmin(admin.ModelAdmin):
-        pass
-
-    @admin.register(EveSovereigntyMap)
-    class EveSovereigntyMapAdmin(admin.ModelAdmin):
-        list_display = (
-            "solar_system_id",
-            "alliance_id",
-            "corporation_id",
-            "faction_id",
-        )
-        search_fields = [
-            "solar_system_id",
-            "alliance_id",
-            "corporation_id",
-            "faction_id",
-        ]
-
-
 class RenderableNotificationFilter(admin.SimpleListFilter):
     title = "can be send"
 
@@ -261,10 +192,10 @@ class NotificationAdmin(admin.ModelAdmin):
     )
 
     def has_add_permission(self, request):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
     def has_change_permission(self, request, obj=None):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
 
 class OwnerSyncStatusFilter(admin.SimpleListFilter):
@@ -283,15 +214,17 @@ class OwnerSyncStatusFilter(admin.SimpleListFilter):
         """Return the filtered queryset"""
         if self.value() == "yes":
             return queryset.filter(
-                structures_last_error=Owner.ERROR_NONE,
-                notifications_last_error=Owner.ERROR_NONE,
-                forwarding_last_error=Owner.ERROR_NONE,
+                structures_last_update_ok=True,
+                notifications_last_update_ok=True,
+                forwarding_last_update_ok=True,
+                assets_last_update_ok=True,
             )
         elif self.value() == "no":
             return queryset.exclude(
-                structures_last_error=Owner.ERROR_NONE,
-                notifications_last_error=Owner.ERROR_NONE,
-                forwarding_last_error=Owner.ERROR_NONE,
+                structures_last_update_ok=True,
+                notifications_last_update_ok=True,
+                forwarding_last_update_ok=True,
+                assets_last_update_ok=True,
             )
         else:
             return queryset
@@ -302,16 +235,13 @@ class OwnerAdmin(admin.ModelAdmin):
     list_display = (
         "_corporation",
         "_alliance",
-        "character",
+        "character_ownership",
         "_is_active",
         "_webhooks",
         "_has_default_pings_enabled",
         "_ping_groups",
         "_is_alliance_main",
-        "_is_structure_sync_ok",
-        "_is_notification_sync_ok",
-        "_is_forwarding_sync_ok",
-        "_is_asset_sync_ok",
+        "_is_sync_ok",
         "_structures_count",
         "_notifications_count",
     )
@@ -331,9 +261,9 @@ class OwnerAdmin(admin.ModelAdmin):
             qs.select_related(
                 "corporation",
                 "corporation__alliance",
-                "character",
-                "character__user",
-                "character__character",
+                "character_ownership",
+                "character_ownership__user",
+                "character_ownership__character",
             )
             .prefetch_related("ping_groups", "webhooks")
             .annotate(notifications_count=Count("notifications", distinct=True))
@@ -384,41 +314,14 @@ class OwnerAdmin(admin.ModelAdmin):
 
     _is_alliance_main.short_description = "alliance main"
 
-    def _is_structure_sync_ok(self, obj):
+    def _is_sync_ok(self, obj):
         if not obj.is_active:
             return None
         else:
-            return obj.is_structure_sync_ok
+            return obj.are_all_syncs_ok
 
-    _is_structure_sync_ok.boolean = True
-    _is_structure_sync_ok.short_description = "structure sync"
-
-    def _is_notification_sync_ok(self, obj):
-        if not obj.is_active:
-            return None
-        else:
-            return obj.is_notification_sync_ok
-
-    _is_notification_sync_ok.boolean = True
-    _is_notification_sync_ok.short_description = "notification sync"
-
-    def _is_forwarding_sync_ok(self, obj):
-        if not obj.is_active:
-            return None
-        else:
-            return obj.is_forwarding_sync_ok
-
-    _is_forwarding_sync_ok.boolean = True
-    _is_forwarding_sync_ok.short_description = "forwarding"
-
-    def _is_asset_sync_ok(self, obj):
-        if not obj.is_active:
-            return None
-        else:
-            return obj.is_asset_sync_ok
-
-    _is_asset_sync_ok.boolean = True
-    _is_asset_sync_ok.short_description = "assets sync"
+    _is_sync_ok.boolean = True
+    _is_sync_ok.short_description = "sync ok"
 
     def _notifications_count(self, obj: Owner) -> int:
         return obj.notifications_count
@@ -470,21 +373,27 @@ class OwnerAdmin(admin.ModelAdmin):
     fetch_notifications.short_description = "Fetch notifications from EVE server"
 
     def has_add_permission(self, request):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
     def get_readonly_fields(self, request, obj=None):
         if obj:  # editing an existing object
             return self.readonly_fields + (
+                "assets_last_update_at",
+                "assets_last_update_ok",
                 "corporation",
-                "character",
-                "notifications_last_error",
-                "notifications_last_sync",
-                "structures_last_error",
-                "structures_last_sync",
-                "forwarding_last_sync",
-                "forwarding_last_error",
-                "assets_last_sync",
-                "assets_last_error",
+                "character_ownership",
+                "forwarding_last_update_at",
+                "forwarding_last_update_ok",
+                "notifications_last_update_at",
+                "notifications_last_update_ok",
+                "structures_last_update_at",
+                "structures_last_update_ok",
+                "_avg_turnaround_time",
+                "_are_all_syncs_ok",
+                "_structures_last_update_fresh",
+                "_notifications_last_update_fresh",
+                "_forwarding_last_update_fresh",
+                "_assets_last_update_fresh",
             )
         return self.readonly_fields
 
@@ -495,7 +404,7 @@ class OwnerAdmin(admin.ModelAdmin):
             {
                 "fields": (
                     "corporation",
-                    "character",
+                    "character_ownership",
                     "webhooks",
                     "is_alliance_main",
                     "are_pocos_public",
@@ -511,21 +420,27 @@ class OwnerAdmin(admin.ModelAdmin):
             {
                 "classes": ("collapse",),
                 "fields": (
+                    "_are_all_syncs_ok",
                     (
-                        "structures_last_sync",
-                        "structures_last_error",
+                        "structures_last_update_ok",
+                        "_structures_last_update_fresh",
+                        "structures_last_update_at",
                     ),
                     (
-                        "notifications_last_sync",
-                        "notifications_last_error",
+                        "notifications_last_update_ok",
+                        "_notifications_last_update_fresh",
+                        "notifications_last_update_at",
+                        "_avg_turnaround_time",
                     ),
                     (
-                        "forwarding_last_sync",
-                        "forwarding_last_error",
+                        "forwarding_last_update_ok",
+                        "_forwarding_last_update_fresh",
+                        "forwarding_last_update_at",
                     ),
                     (
-                        "assets_last_sync",
-                        "assets_last_error",
+                        "assets_last_update_ok",
+                        "_assets_last_update_fresh",
+                        "assets_last_update_at",
                     ),
                 ),
             },
@@ -539,6 +454,96 @@ class OwnerAdmin(admin.ModelAdmin):
 
         return super().formfield_for_manytomany(db_field, request, **kwargs)
 
+    def _are_all_syncs_ok(self, obj):
+        return obj.are_all_syncs_ok
+
+    _are_all_syncs_ok.boolean = True
+    _are_all_syncs_ok.short_description = "All syncs OK"
+
+    def _avg_turnaround_time(self, obj) -> str:
+        """Average time between timestamp of notifications an when they are received."""
+
+        def my_format(value) -> str:
+            return f"{value:,.0f}" if value else "-"
+
+        max_short = app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_SHORT
+        max_medium = app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_MEDIUM
+        max_long = app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_LONG
+        max_valid = app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_MAX_VALID
+        notifications = obj.notifications.filter(created__isnull=False).order_by(
+            "-timestamp"
+        )
+        data = [
+            (rec[0] - rec[1]).total_seconds()
+            for rec in notifications.values_list("created", "timestamp")
+            if (rec[0] - rec[1]).total_seconds() < max_valid
+        ]
+        short = statistics.mean(data[:max_short]) if len(data) >= max_short else None
+        medium = statistics.mean(data[:max_medium]) if len(data) >= max_medium else None
+        long = statistics.mean(data[:max_long]) if len(data) >= max_long else None
+        return f"{my_format(short)} | {my_format(medium)} | {my_format(long)}"
+
+    _avg_turnaround_time.short_description = "Avg. turnaround time"
+
+    def _structures_last_update_fresh(self, obj) -> int:
+        return obj.is_structure_sync_fresh
+
+    _structures_last_update_fresh.boolean = True
+    _structures_last_update_fresh.short_description = "Last update fresh"
+
+    def _notifications_last_update_fresh(self, obj) -> int:
+        return obj.is_notification_sync_fresh
+
+    _notifications_last_update_fresh.boolean = True
+    _notifications_last_update_fresh.short_description = "Last update fresh"
+
+    def _forwarding_last_update_fresh(self, obj) -> int:
+        return obj.is_forwarding_sync_fresh
+
+    _forwarding_last_update_fresh.boolean = True
+    _forwarding_last_update_fresh.short_description = "Last update fresh"
+
+    def _assets_last_update_fresh(self, obj) -> int:
+        return obj.is_assets_sync_fresh
+
+    _assets_last_update_fresh.boolean = True
+    _assets_last_update_fresh.short_description = "Last update fresh"
+
+    def get_form(self, *args, **kwargs):
+        """Add help text to custom field."""
+        help_texts = {
+            "_avg_turnaround_time": (
+                "For last %d | %d | %d notifications"
+                % (
+                    app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_SHORT,
+                    app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_MEDIUM,
+                    app_settings.STRUCTURES_NOTIFICATION_TURNAROUND_LONG,
+                )
+            ),
+            "_are_all_syncs_ok": (
+                "True when all syncs were successful and not older then "
+                "the respective grace period."
+            ),
+            "_structures_last_update_fresh": (
+                "True when last sync within %s minutes."
+                % app_settings.STRUCTURES_STRUCTURE_SYNC_GRACE_MINUTES
+            ),
+            "_notifications_last_update_fresh": (
+                "True when last sync within %s minutes."
+                % app_settings.STRUCTURES_NOTIFICATION_SYNC_GRACE_MINUTES
+            ),
+            "_forwarding_last_update_fresh": (
+                "True when last sync within %s minutes."
+                % app_settings.STRUCTURES_NOTIFICATION_SYNC_GRACE_MINUTES
+            ),
+            "_assets_last_update_fresh": (
+                "True when last sync within %s minutes."
+                % app_settings.STRUCTURES_STRUCTURE_SYNC_GRACE_MINUTES
+            ),
+        }
+        kwargs.update({"help_texts": help_texts})
+        return super().get_form(*args, **kwargs)
+
 
 @admin.register(StructureTag)
 class StructureTagAdmin(admin.ModelAdmin):
@@ -568,13 +573,13 @@ class StructureAdminInline(admin.TabularInline):
     model = StructureService
 
     def has_add_permission(self, request, obj=None):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
     def has_change_permission(self, request, obj=None):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
     def has_delete_permission(self, request, obj=None):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
 
 class OwnerCorporationsFilter(admin.SimpleListFilter):
@@ -698,7 +703,7 @@ class StructureAdmin(admin.ModelAdmin):
     _tags.short_description = "Tags"
 
     def has_add_permission(self, request):
-        return True if STRUCTURES_DEVELOPER_MODE else False
+        return False
 
     def add_default_tags(self, request, queryset):
         structure_count = 0
@@ -746,15 +751,13 @@ class StructureAdmin(admin.ModelAdmin):
         "Update generated tags for selected structures"
     )
 
-    if not STRUCTURES_DEVELOPER_MODE:
-        readonly_fields = tuple(
-            [
-                x.name
-                for x in Structure._meta.get_fields()
-                if isinstance(x, models.fields.Field) and x.name not in ["tags"]
-            ]
-        )
-
+    readonly_fields = tuple(
+        [
+            x.name
+            for x in Structure._meta.get_fields()
+            if isinstance(x, models.fields.Field) and x.name not in ["tags"]
+        ]
+    )
     fieldsets = (
         (None, {"fields": ("name", "owner", "eve_solar_system", "eve_type", "tags")}),
         (
