@@ -33,11 +33,6 @@ STRUCTURES_FEATURE_CUSTOMS_OFFICES = clean_setting(
 # Whether the starbases / POSes feature is active
 STRUCTURES_FEATURE_STARBASES = clean_setting("STRUCTURES_FEATURE_STARBASES", True)
 
-# Max time in minutes since last successful notification forwarding
-# before service is reported as down
-STRUCTURES_FORWARDING_SYNC_GRACE_MINUTES = clean_setting(
-    "STRUCTURES_FORWARDING_SYNC_GRACE_MINUTES", 5
-)
 
 # defines after how many hours a notification becomes stale
 # stale notification will no longer be sent automatically
@@ -59,7 +54,7 @@ STRUCTURES_NOTIFICATION_MAX_RETRIES = clean_setting(
 # Max time in minutes since last successful notification sync
 # before service is reported as down
 STRUCTURES_NOTIFICATION_SYNC_GRACE_MINUTES = clean_setting(
-    "STRUCTURES_NOTIFICATION_SYNC_GRACE_MINUTES", 15
+    "STRUCTURES_NOTIFICATION_SYNC_GRACE_MINUTES", 20
 )
 
 # Default wait time in seconds before retrying to send a notification
@@ -116,3 +111,26 @@ STRUCTURES_DEFAULT_PAGE_LENGTH = clean_setting("STRUCTURES_DEFAULT_PAGE_LENGTH",
 
 # Wether paging is enabled for the structure list
 STRUCTURES_PAGING_ENABLED = clean_setting("STRUCTURES_PAGING_ENABLED", True)
+
+# INTERNAL SETTINGS
+
+# Number of notifications to count for short mean turnaround time
+STRUCTURES_NOTIFICATION_TURNAROUND_SHORT = clean_setting(
+    "STRUCTURES_NOTIFICATION_TURNAROUND_SHORT", 5
+)
+
+# Number of notifications to count for medium mean turnaround time
+STRUCTURES_NOTIFICATION_TURNAROUND_MEDIUM = clean_setting(
+    "STRUCTURES_NOTIFICATION_TURNAROUND_MEDIUM", 15
+)
+
+# Number of notifications to count for long mean turnaround time
+STRUCTURES_NOTIFICATION_TURNAROUND_LONG = clean_setting(
+    "STRUCTURES_NOTIFICATION_TURNAROUND_LONG", 50
+)
+
+# Turnaround duration with more than x seconds are regarded as outliers
+# and will be ignored when calculating the averages
+STRUCTURES_NOTIFICATION_TURNAROUND_MAX_VALID = clean_setting(
+    "STRUCTURES_NOTIFICATION_TURNAROUND_MAX_VALID", 3600
+)
