@@ -1,3 +1,5 @@
+from typing import Optional
+
 from celery import chain, shared_task
 
 from django.contrib.auth.models import User
@@ -5,6 +7,7 @@ from django.contrib.auth.models import User
 from allianceauth.notifications import notify
 from allianceauth.services.hooks import get_extension_logger
 from allianceauth.services.tasks import QueueOnce
+from app_utils.esi import fetch_esi_status
 from app_utils.logging import LoggerAddTag
 
 from . import __title__
@@ -16,36 +19,28 @@ logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 TASK_PRIO_HIGH = 2
 
 
-@shared_task(base=QueueOnce)
-def send_messages_for_webhook(webhook_pk: int) -> None:
-    """sends all currently queued messages for given webhook to Discord"""
-    Webhook.objects.send_queued_messages_for_webhook(webhook_pk)
+@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
+def update_all_structures():
+    """Update all structures.
+
+    Main task for starting regular update of all structures
+    and related data from ESI.
+    """
+    if not fetch_esi_status().is_ok:
+        logger.warning("ESI currently not available. Aborting.")
+    else:
+        chain(update_sov_map.si(), update_structures.si()).delay()
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def update_structures_for_owner(owner_pk, user_pk=None):
-    """fetches all structures for owner and update the corp assets related to them from ESI"""
-    chain(
-        update_structures_esi_for_owner.si(owner_pk, user_pk),
-        update_structures_assets_for_owner.si(owner_pk, user_pk),
-    ).delay()
-
-
-@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def update_structures_esi_for_owner(owner_pk, user_pk=None):
-    """fetches all structures for owner"""
-    _get_owner(owner_pk).update_structures_esi(_get_user(user_pk))
-
-
-@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def update_structures_assets_for_owner(owner_pk, user_pk=None):
-    """fetches all structures for owner"""
-    _get_owner(owner_pk).update_asset_esi(_get_user(user_pk))
+def update_sov_map():
+    """Update sovereignty map from ESI."""
+    EveSovereigntyMap.objects.update_from_esi()
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
 def update_structures():
-    """fetches all structures for all active owner from ESI"""
+    """Update all structures for all active owners from ESI."""
     for owner in Owner.objects.all():
         if owner.is_active:
             update_structures_for_owner.delay(owner.pk)
@@ -61,35 +56,32 @@ def update_structures():
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def update_sov_map():
-    """updates the sovereignty map"""
-    EveSovereigntyMap.objects.update_from_esi()
+def update_structures_for_owner(owner_pk, user_pk=None):
+    """Fetch all structures for owner and update related corp assets from ESI."""
+    if not fetch_esi_status().is_ok:
+        logger.warning("ESI currently not available. Aborting.")
+    else:
+        chain(
+            update_structures_esi_for_owner.si(owner_pk, user_pk),
+            update_structures_assets_for_owner.si(owner_pk, user_pk),
+        ).delay()
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def update_all_structures():
-    """main task for starting regular update of all structures
-    and related data from ESI
-    """
-    chain(update_sov_map.si(), update_structures.si()).delay()
+def update_structures_esi_for_owner(owner_pk, user_pk=None):
+    """Update all structures for owner for ESI."""
+    _get_owner(owner_pk).update_structures_esi(_get_user(user_pk))
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def process_notifications_for_owner(owner_pk, user_pk=None):
-    """fetches all notification for owner from ESI and processes them"""
-    owner = _get_owner(owner_pk)
-    owner.fetch_notifications_esi(_get_user(user_pk))
-    owner.send_new_notifications()
-    for webhook in owner.webhooks.filter(is_active=True):
-        if webhook.queue_size() > 0:
-            send_messages_for_webhook.apply_async(
-                kwargs={"webhook_pk": webhook.pk}, priority=TASK_PRIO_HIGH
-            )
+def update_structures_assets_for_owner(owner_pk, user_pk=None):
+    """Update all related assets for owner."""
+    _get_owner(owner_pk).update_asset_esi(_get_user(user_pk))
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
 def fetch_all_notifications():
-    """fetch notifications for all owners"""
+    """Fetch notifications for all owners."""
     for owner in Owner.objects.all():
         if owner.is_active:
             process_notifications_for_owner.apply_async(
@@ -97,9 +89,25 @@ def fetch_all_notifications():
             )
 
 
+@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
+def process_notifications_for_owner(owner_pk, user_pk=None):
+    """Fetch all notification for owner from ESI and processes them."""
+    if not fetch_esi_status().is_ok:
+        logger.warning("ESI currently not available. Aborting.")
+    else:
+        owner = _get_owner(owner_pk)
+        owner.fetch_notifications_esi(_get_user(user_pk))
+        owner.send_new_notifications()
+        for webhook in owner.webhooks.filter(is_active=True):
+            if webhook.queue_size() > 0:
+                send_messages_for_webhook.apply_async(
+                    kwargs={"webhook_pk": webhook.pk}, priority=TASK_PRIO_HIGH
+                )
+
+
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
 def send_notifications(notification_pks: list) -> None:
-    """send notifications defined by list of pks (used for admin action)"""
+    """Send notifications defined by list of pks (used for admin action)."""
     notifications = Notification.objects.filter(pk__in=notification_pks)
     if notifications:
         logger.info(
@@ -124,9 +132,15 @@ def send_notifications(notification_pks: list) -> None:
             )
 
 
+@shared_task(base=QueueOnce)
+def send_messages_for_webhook(webhook_pk: int) -> None:
+    """Send all currently queued messages for given webhook to Discord."""
+    Webhook.objects.send_queued_messages_for_webhook(webhook_pk)
+
+
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
 def send_test_notifications_to_webhook(webhook_pk, user_pk=None) -> None:
-    """sends test notification to given webhook"""
+    """Send test notification to given webhook."""
     try:
         webhook = Webhook.objects.get(pk=webhook_pk)
         if user_pk:
@@ -157,7 +171,7 @@ def send_test_notifications_to_webhook(webhook_pk, user_pk=None) -> None:
 
 
 def _get_owner(owner_pk: int) -> Owner:
-    """returns the owner or raises exception"""
+    """Fetch the owner or raise exception."""
     try:
         owner = Owner.objects.get(pk=owner_pk)
     except Owner.DoesNotExist:
@@ -167,12 +181,12 @@ def _get_owner(owner_pk: int) -> Owner:
     return owner
 
 
-def _get_user(user_pk: int) -> User:
-    """returns the user or None. Logs if user is requested but can't be found."""
+def _get_user(user_pk: int) -> Optional[User]:
+    """Fetch the user or return None."""
     user = None
     if user_pk:
         try:
             user = User.objects.get(pk=user_pk)
         except User.DoesNotExist:
-            logger.warning("Ignoring non-existing user with pk {}".format(user_pk))
+            logger.warning("Ignoring non-existing user with pk %s", user_pk)
     return user
