@@ -1,6 +1,8 @@
+import datetime as dt
 import re
 import urllib
 from enum import IntEnum
+from typing import Optional
 
 from django.contrib.auth.decorators import login_required, permission_required
 from django.contrib.staticfiles.storage import staticfiles_storage
@@ -123,10 +125,26 @@ def main(request):
         "tags_exist": StructureTag.objects.exists(),
         "data_tables_page_length": STRUCTURES_DEFAULT_PAGE_LENGTH,
         "data_tables_paging": STRUCTURES_PAGING_ENABLED,
+        "last_updated": _last_updated(),
     }
     return render(request, "structures/main.html", context)
 
 
+# TODO: Move to manager
+def _last_updated() -> Optional[dt.datetime]:
+    """Date/time when structures were last updated."""
+    active_owners = Owner.objects.filter(is_active=True)
+    return (
+        (
+            active_owners.order_by("-structures_last_update_at")
+            .first()
+            .structures_last_update_at
+        )
+        if active_owners
+        else None
+    )
+
+
 class StructuresRowBuilder:
     """This class build the HTML table rows from structure objects."""
 
@@ -164,8 +182,16 @@ class StructuresRowBuilder:
             corporation.corporation_name,
             alliance_name,
         )
+        if not self._structure.owner.is_structure_sync_ok:
+            update_warning_html = format_html(
+                '<i class="fas fa-exclamation-circle text-warning" '
+                'title="Sync has issues. Data may be outdated."></i>'
+            )
+        else:
+            update_warning_html = ""
         self._row["corporation_icon"] = format_html(
-            '<img src="{}" width="{}" height="{}"/>',
+            '<span class="nowrap">{} <img src="{}" width="{}" height="{}"/></span>',
+            update_warning_html,
             corporation.logo_url(size=STRUCTURE_LIST_ICON_RENDER_SIZE),
             STRUCTURE_LIST_ICON_OUTPUT_SIZE,
             STRUCTURE_LIST_ICON_OUTPUT_SIZE,
@@ -478,8 +504,8 @@ def _structures_query_for_user(request):
             "structures.view_corporation_structures"
         ) or request.user.has_perm("structures.view_alliance_structures"):
             corporation_ids = {
-                character.character.corporation_id
-                for character in request.user.character_ownerships.all()
+                character_ownership.character.corporation_id
+                for character_ownership in request.user.character_ownerships.all()
             }
             corporations = list(
                 EveCorporationInfo.objects.select_related("alliance").filter(
@@ -602,7 +628,7 @@ def structure_details(request, structure_id):
         },
         "assets_grouped": assets_grouped,
         "structure": structure,
-        "last_updated": structure.owner.assets_last_sync,
+        "last_updated": structure.owner.assets_last_update_at,
     }
     return render(request, "structures/modals/structure_details.html", context)
 
@@ -670,7 +696,7 @@ def add_structure_owner(request, token):
             )
 
         owner, _ = Owner.objects.update_or_create(
-            corporation=corporation, defaults={"character": owned_char}
+            corporation=corporation, defaults={"character_ownership": owned_char}
         )
         default_webhooks = Webhook.objects.filter(is_default=True)
         if default_webhooks:
@@ -693,7 +719,8 @@ def add_structure_owner(request, token):
                 % {
                     "corporation": format_html("<strong>{}</strong>", owner),
                     "character": format_html(
-                        "<strong>{}</strong>", owner.character.character.character_name
+                        "<strong>{}</strong>",
+                        owner.character_ownership.character.character_name,
                     ),
                 }
             ),
